intelmq.bots.collectors.tcp package — intelmq 3.0.0.alpha.1 documentation

# intelmq.bots.collectors.tcp package

## Submodules

## intelmq.bots.collectors.tcp.collector module

`intelmq.bots.collectors.tcp.collector.` `BOT`

  alias of `intelmq.bots.collectors.tcp.collector.TCPCollectorBot`

class `intelmq.bots.collectors.tcp.collector.` `TCPCollectorBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.CollectorBot`

  Receive events by opening a TCP port (ex: from TCP Output of another IntelMQ instance)

  `connect`()
  `init`()
  `ip`: str = '<ip>'
  `port`: int = '<port>'
  `process`()
  `recvall`(conn, n)
  `shutdown`()

## Module contents